moody API documentation

# Package `moody`

Expand source code

    # Token = namedtuple('Token', ['address', 'name', 'code_hash'], defaults=(None,) * 3)
    from dataclasses import dataclass

    @dataclass
    class Token:
        address: str = None
        name: str = None
        code_hash: str = None
        token_contract: str = None

    @dataclass
    class Config:
        network_name: str
        rpc_url: str
        chain_id: int
        symbol: str
        block_explorer: str

## Sub-modules

`moody.bridge`
`moody.buildercompile`
`moody.conf`
`moody.erc20`
`moody.libeb`
`moody.m`
`moody.paths`

  Base wrapper class for accessing ethereum smart contracts.

## Classes

`class Config (network_name: str, rpc_url: str, chain_id: int, symbol: str, block_explorer: str)`

  Config(network_name: str, rpc_url: str, chain_id: int, symbol: str, block_explorer: str)

  Expand source code

      class Config:
          network_name: str
          rpc_url: str
          chain_id: int
          symbol: str
          block_explorer: str

  ### Class variables

  `var block_explorer : str`
  `var chain_id : int`
  `var network_name : str`
  `var rpc_url : str`
  `var symbol : str`
`class Token (address: str = None, name: str = None, code_hash: str = None, token_contract: str = None)`

  Token(address: str = None, name: str = None, code_hash: str = None, token_contract: str = None)

  Expand source code

      class Token:
          address: str = None
          name: str = None
          code_hash: str = None
          token_contract: str = None

  ### Class variables

  `var address : str`
  `var code_hash : str`
  `var name : str`
  `var token_contract : str`